package com.ruoyi.ss.channelWithdraw.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.ss.channelWithdraw.domain.ChannelWithdraw;
import com.ruoyi.ss.channelWithdraw.domain.ChannelWithdrawVO;
import com.ruoyi.ss.channelWithdraw.domain.ChannelWithdrawQuery;

/**
 * 提现渠道Service接口
 *
 * @author ruoyi
 * @date 2024-08-02
 */
public interface ChannelWithdrawService
{
    /**
     * 查询提现渠道
     *
     * @param channelId 提现渠道主键
     * @return 提现渠道
     */
    public ChannelWithdrawVO selectChannelWithdrawByChannelId(Long channelId);

    /**
     * 查询提现渠道列表
     *
     * @param channelWithdraw 提现渠道
     * @return 提现渠道集合
     */
    public List<ChannelWithdrawVO> selectChannelWithdrawList(ChannelWithdrawQuery channelWithdraw);

    /**
     * 新增提现渠道
     *
     * @param channelWithdraw 提现渠道
     * @return 结果
     */
    public int insertChannelWithdraw(ChannelWithdraw channelWithdraw);

    /**
     * 修改提现渠道
     *
     * @param channelWithdraw 提现渠道
     * @return 结果
     */
    public int updateChannelWithdraw(ChannelWithdraw channelWithdraw);

    /**
     * 批量删除提现渠道
     *
     * @param channelIds 需要删除的提现渠道主键集合
     * @return 结果
     */
    public int deleteChannelWithdrawByChannelIds(Long[] channelIds);

    /**
     * 删除提现渠道信息
     *
     * @param channelId 提现渠道主键
     * @return 结果
     */
    public int deleteChannelWithdrawByChannelId(Long channelId);

    /**
     * 查询用户可用的提现渠道
     */
    List<ChannelWithdrawVO> selectEnabledList(Long userId);

    /**
     * 查询启用渠道
     * @return
     */
    List<ChannelWithdrawVO> selectEnabledList();
}
